WithEpitaph

Trait WithEpitaph 

pub trait WithEpitaph: Sized {
    // Required method
    fn with_epitaph<E>(self, epitaph: E) -> StreamWithEpitaph<Self, E>;
}
Extension trait to allow for easy creation of a StreamWithEpitaph from a Stream.

Required Methods

fn with_epitaph<E>(self, epitaph: E) -> StreamWithEpitaph<Self, E>

Map this stream to one producing a StreamItem::Item value for each item of the stream followed by a single StreamItem::Epitaph value with the provided epitaph.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> WithEpitaph for T
where T: Stream,