WithTag

Trait WithTag 

pub trait WithTag: Sized {
    // Required method
    fn tagged<T>(self, tag: T) -> Tagged<T, Self> ;
}
Extension trait to allow for easy creation of a Tagged stream from a Stream.

Required Methods

fn tagged<T>(self, tag: T) -> Tagged<T, Self>

Produce a new stream from this one which yields item tupled with a constant tag

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<St: Sized> WithTag for St